<?php

namespace App\Http\Controllers;

use App\Interfaces\IBranch;
use App\Interfaces\ICompany;
use App\Interfaces\IPrivilage;
use App\Interfaces\IRole;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Tymon\JWTAuth\Facades\JWTAuth;

class AuthController extends Controller
{

    private $privilege, $company, $branch, $role;

    /**
     * Create a new controller instance.
     *
     * @return void
     */

    public function __construct(IPrivilage $privilege, ICompany $company, IBranch $branch, IRole $role)
    {
        $this->privilege = $privilege;
        $this->company = $company;
        $this->branch = $branch;
        $this->role = $role;
    }



    public function login(Request $request)
    {
        $validator = Validator::make($request->all() ,[
            'email'=> 'required|string',
            'password'=> 'required|string'
        ]);

        if($validator->fails()){
            return $this->sendError('Validation Error- '. $validator->errors()->first(),$validator->errors());
        }


        $user = User::where("email", $request->get('email'))->first();

        if(is_null($user)){
            return $this->sendError('Invalid email and password combination');
        }

        if(!Hash::check($request->get("password"), $user->password)){

            return $this->sendError('Invalid email and password combination');
        }



        if($user->active_flag==0){
            return $this->sendError("You are currently not allowed to login,please contact the administration");
        }

        $token = JWTAuth::fromUser($user);

        $data = [];

        $user_company = $this->company->findItem(['id'=> $user->client_id]);


        if(is_null($user_company)){
            return $this->sendError("You are currently not allowed to login,please contact the administration");
        }

        $data['claims'] = $this->privilege->getUserClaims($user->role_id);

        $data['branches'] = $this->branch->userBranch($user->id);

        //get user branches
       
        // if($user->super_user == 0){

        //     //get user claims
        //     $data['claims'] = $this->privilege->getUserClaims($user->role_id);


         
        // }else{

           
        //     $data['claims'] = $this->privilege->getUserClaims($user->role_id);
        // }

       

        $data['profile'] = (object) [
            'user_id'=> $user->id,
            'first_name'=> $user->first_name,
            'last_name'=> $user->last_name,
            'email'=> $user->email,
            'phone_number'=> $user->phone_number,
            'last_login_date'=> $user->last_login_date,
            'client_id'=> $user->id,
            'client_slug'=> $user_company->client_slug,
            // 'company_logo'=> $user_company->logo,
            'role'=> $this->role->findItem(['id'=> $user->role_id])->name
        ];

        return response()->json([
            'token'=> $token,
            'token_type'=> 'bearer',
            'expires_in'=> Auth::factory()->getTTL() * 60,
            'user'=> $data,
            'status'=> 1
        ], 200);
    }


    public function checkToken(Request $request)
    {
        $token = $request->get('token');

        $check = DB::table('password_resets')->where('token', $token)->first();

        if(is_null($check)){
            return $this->sendError('Token does not exist');
        }

        $current_date = Carbon::now();
        if($current_date > $check->expire_time){
            return $this->sendError('Token has expired');
        }

        return $this->sendResponse(true,true);
    }
}
