<?php

namespace App\Http\Controllers;

use App\Interfaces\ILicense;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class LicenseController extends Controller
{

    protected $license;

    public function __construct(ILicense $license)
    {
        $this->license = $license;
    }

    public function index()
    {
        $response = $this->license->license();

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function getLicense($id)
    {
        $response = $this->license->findlicense($id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function create(Request $request)
    {
        $validate = Validator::make($request->all(), [
            'license_name' => 'required|string|max:191',
            'number_of_days' => 'required|numeric'
        ]);

        if ($validate->fails()) {
            return $this->sendError("Validation Error - {$validate->errors()->first()}", $validate->errors());
        }

        $response = $this->license->createLicense($request->all());

        return $this->sendHttpStatusResponse($response->body, $response->status_code);

    }

    public function update(Request $request, $id)
    {
        $validate = Validator::make($request->all(), [
            'license_name' => 'required|string|max:191',
            'number_of_days' => 'required|numeric'
        ]);

        if ($validate->fails()) {
            return $this->sendError("Validation Error - {$validate->errors()->first()}", $validate->errors());
        }

        $response = $this->license->updateLicense($request->all(), $id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function disable($id)
    {
        
        $response = $this->license->disableLicense($id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function enable($id)
    {
        $response = $this->license->enableLicense($id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function Renewal(Request $request)
    {
        $validate = Validator::make($request->all(), [
            'client_slug' => 'required',
            'license_id' => 'required|integer'
        ]);

        if ($validate->fails()) {
            return $this->sendError("Validation Error - {$validate->errors()->first()}", $validate->errors());
        }

        $response = $this->license->renewLicense($request->all());

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function Runninglicense()
    {
        $response = $this->license->runninglicense();

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
        
    }

    public function Expiredlicense()
    {
        $response = $this->license->expiredlicense();

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function LicenseHistory($client_slug)
    {
        $response = $this->license->licensehistory($client_slug);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }
}
