<?php

namespace App\Http\Controllers;

use App\Interfaces\ISector;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class SectorController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */

    public $sector;

    public function __construct(ISector $sector)
    {
        $this->sector = $sector;
    }


    public function sector()
    {
        $response = $this->sector->sectors();

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function find($id)
    {
        $response = $this->sector->getSector($id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function create(Request $request)
    {
        $validate = Validator::make($request->all(), [
            'sector_name'=> 'required'
        ]);

        if($validate->fails()){
            return $this->sendError("Validation Error - {$validate->errors()->first()}", $validate->errors());
        }

        $response = $this->sector->createSector($request->all());

        return $this->sendHttpStatusResponse($response->body, $response->status_code);

    }

    public function update(Request $request, $id)
    {
        $validate = Validator::make($request->all(), [
            'sector_name' => 'required'
        ]);

        if($validate->fails()){
            return $this->sendError("Validation Error - {$validate->errors()->first()}", $validate->errors());
        }

        $response = $this->sector->updateSector($request->all(), $id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function disable_sector($id)
    {
        $response = $this->sector->disableSector($id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function enable_sector($id)
    {
        $response = $this->sector->enableSector($id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }
    
}
