<?php

namespace App\Http\Controllers\Survey;

use App\Http\Controllers\Controller;
use App\Interfaces\Survey\IQuestion;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class QuestionController extends Controller
{
    protected $question;

    public function __construct(IQuestion $question)
    {
        $this->question = $question;
    }

    public function surveyquestions($client_slug, $survey_id)
    {
        $response = $this->question->surveyQuestions($client_slug, $survey_id);
        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function createsurveyQuestion(Request $request, $client_slug, $survey_id)
    {
        $validate = Validator::make($request->all(), [
            "questions" => "required|array",
            "questions.*" => "required|array",
            "questions.*.question" => "required|string",
            "questions.*.response_type" => "required|numeric",
            "questions.*.response_group" => "nullable|numeric",
            "questions.*" => "required|array",
        ]);

        if($validate->fails()){
            return $this->sendError("Validation Error - {$validate->errors()->first()}", $validate->errors());
        }

        $response = $this->question->createSurveyQuestion($request->all(), $client_slug, $survey_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);

    }

    public function updatesurveyQuestion(Request $request, $client_slug, $survey_id, $question_id)
    {
        $validate = Validator::make($request->all(), [
            "question" => "required",
            "response_type" => "required|numeric",
            "response_group" => "nullable|numeric"
        ]);

        if ($validate->fails()) {
            return $this->sendError("Validation Error - {$validate->errors()->first()}", $validate->errors());
        }

        $response = $this->question->updateSurveyQuestion($request->all(), $client_slug, $survey_id, $question_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function disablesurveyQuestion($client_slug, $survey_id, $question_id)
    {
        $response = $this->question->disableSurveyQuestion($client_slug, $survey_id, $question_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }

    public function enablesurveyQuestion($client_slug, $survey_id, $question_id)
    {
        $response = $this->question->enableSurveyQuestion($client_slug, $survey_id, $question_id);

        return $this->sendHttpStatusResponse($response->body, $response->status_code);
    }
}
