<?php

namespace App\Http\Middleware;

use App\Traits\AuthorizeTrait;
use Closure;
use Illuminate\Contracts\Auth\Factory as Auth;
use Illuminate\Support\Facades\DB;


class AuthorizeMiddleware
{

    use AuthorizeTrait;

    /**
     * The authentication guard factory instance.
     *
     * @var \Illuminate\Contracts\Auth\Factory
     */
    protected $auth;

    /**
     * Create a new middleware instance.
     *
     * @param  \Illuminate\Contracts\Auth\Factory  $auth
     * @return void
     */
    public function __construct(Auth $auth)
    {
        $this->auth = $auth;
    }


    public function handle($request, Closure $next, $permission = null, $action = null)
    {

        if ($this->auth->guard()->guest()) {
            return response(["message" => "User is not authorized"], 401);
        }

        $user = $request->user();

        if (!$this->isUserAuthorized($user, $permission, $action)) {
            return response(["message" => "User is not authorized"], 401);
        }

        return $next($request);
    }
}
