<?php

namespace App\Repo;


use App\Interfaces\ICompany;
use Illuminate\Support\Facades\DB;

class CompanyRepo extends BaseRepo implements ICompany
{
    protected  $table_name;
    /**
     * @var MakeRequest
     */
    private $makeRequest;

    private $token;

    public function __construct($table_name = "clients")
    {
        parent::__construct($table_name);
        $this->table_name = $table_name;
        $base_url = env("SURVEY_ENGINE_URL");
        $this->makeRequest = new MakeRequest($base_url);
        $this->token = env('ADMIN_TOKEN');

    }

    public function allCompanies()
    {
        
        return $this->makeRequest->getAsJson("company" , [
            'client-Key' => $this->token
        ]);
    }

    public function createClient(array $data)
    {
        return $this->makeRequest->postAsForm("company/create", $data, [
            'client-Key' => $this->token
        ]);
    }

    public function fetchCompany($slug)
    {
        return $this->makeRequest->getAsJson("company/find/{$slug}", [
            'client-Key' => $this->token
        ]);
    }


    public function updateClient(array $data, $client_slug)
    {
        return $this->makeRequest->postAsForm("company/update/{$client_slug}", $data, [
            'client-Key' => $this->token
        ]);
    }


    public function disableCompany($company_slug)
    {

        return $this->makeRequest->postAsJson("company/disable/{$company_slug}",[],[
            'client-Key' => $this->token
        ]);
    }

    public function enableCompany($company_slug)
    {
        return $this->makeRequest->postAsJson("company/enable/{$company_slug}",[],[
            'client-Key' => $this->token
        ]);
    }

    public function companyBranch($company_slug)
    {
        return $this->makeRequest->getAsJson("company/branches/{$company_slug}", [
            'client-Key' => $this->token
        ]);
    }

    public function icons()
    {
        return $this->makeRequest->getAsJson("icons", [
            'client-Key' => $this->token
        ]);
    }

    public function clientIcons(string $client_slug)
    {
        return $this->makeRequest->getAsJson("{$client_slug}/icons", [
            'client-Key' => $this->token
        ]);
    }

    public function backgrounds()
    {
        return $this->makeRequest->getAsJson("banners", [
            'client-Key' => $this->token
        ]);
    }

    public function clientBackgrounds(string $client_slug)
    {
        return $this->makeRequest->getAsJson("{$client_slug}/banners", [
            'client-Key' => $this->token
        ]);
    }
    
}
