<?php


namespace App\Repo;


use App\Traits\HttpErrorTrait;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\ClientException;

class MakeRequest
{
    use HttpErrorTrait;
    /**
     * @var Client
     */
    private $client;

    public function __construct($base_url = "")
    {
        $this->client = new Client([
            'base_uri' => $base_url ?? env("API_URL"),
            'headers' => [
                'Accept' => 'application/json',
                'Content-Type' => 'application/json',
                "APIKEY" => "aBcD1234Efgh"
            ]
        ]);
    }

    public function getAsJson(string $url, array $headers = [])
    {
        try {
            $result = $this->client->get($url, [
                "headers" => $headers
            ]);
            $body = json_decode($result->getBody()->getContents());
            return (object) [
                "body" => $body,
                "status_code" => 200
            ];
        } catch (ClientException $ex) {
            return $this->formulateErrorResponse($ex);
        } catch (\Exception $ex) {
            return $this->formulateErrorResponse($ex);
        }
    }

    public function postAsJson(string $url, array $body = [] , array $headers = [])
    {

        try {
            $result = $this->client->post($url, [
                'json' => $body,
                "headers" => $headers
            ]);



            $body = json_decode($result->getBody()->getContents());
            return (object) [
                "body" => $body,
                "status_code" => 200
            ];
        } catch (ClientException $ex) {
            return $this->formulateErrorResponse($ex);
        } catch (\Exception $ex) {
            return $this->formulateErrorResponse($ex);
        }
    }

    public function postAsForm(string $url, array $body = [], array $headers = [])
    {
        try {
            $result = $this->client->post($url, [
                'multipart' => $body,
                "headers" => $headers
            ]);

            $body = json_decode($result->getBody()->getContents());

            return (object) [
                "body" => $body,
                "status_code" => 200
            ];
        } catch (ClientException $ex) {
            return $this->formulateErrorResponse($ex);
        } catch (\Exception $ex) {
            return $this->formulateErrorResponse($ex);
        }
    }

    public function postAsFormData(string $url, array $body = [], array $headers = [])
    {
        try {
            $result = $this->client->post($url, [
                'form_params' => $body,
                "headers" => $headers
            ]);

            $body = json_decode($result->getBody()->getContents());

            return (object) [
                "body" => $body,
                "status_code" => 200
            ];
        } catch (ClientException $ex) {
            return $this->formulateErrorResponse($ex);
        } catch (\Exception $ex) {
            return $this->formulateErrorResponse($ex);
        }
    }
}
