<?php

namespace App\Repo;

use App\Interfaces\IMenu;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\DB;

class MenuRepo implements IMenu
{

    public function __construct()
    {
    }

    public function getAllActiveMenus()
    {
        $active_menus = DB::table("portal_menus AS pm")
            ->join("privileges AS p", function ($query) {
                $query->on("p.id", "=", "pm.privilege_id")
                    ->where("p.active_flag", 1);
            })->where(["link_flag" => 1, "pm.active_flag" => 1])
            ->select(
                "route_name",
                "parent_id",
                "text",
                "serial_no",
                "link_flag"
            )->get();

        // dd($active_menus);

        $parent_links = $active_menus->where("parent_id", null);

        $children_links = $active_menus->where("parent_id", "<>", null);

        $nested_menus = $this->findParents($children_links);

        foreach ($parent_links as $parent_link) {
            $nested_menus->add($parent_link);
        }
        $links = $nested_menus->sortBy("serial_no")->values()->all();


        return $links;
    }

    public function getUserMenus($user)
    {
        $role_id = $user->role_id;
       
       $active_menus = DB::table("roles_privileges AS rp")
                        ->where('rp.role_id', $role_id)
                        ->join("privileges As p", function($query) {
                             $query->on("p.id", "=", "rp.privilege_id")
                                 ->where("p.active_flag", 1);
                        })
                        ->join("portal_menus AS pm", function($query){
                            $query->on("pm.privilege_id", "=", "rp.privilege_id")
                                         ->where(["pm.link_flag" => 1, "pm.active_flag" => 1]);
                        })
            ->groupBy(
                "pm.id",
                "pm.privilege_id",
                "route_name",
                "parent_id",
                "text",
                "serial_no",
                "link_flag"
            )
            ->select(
                "pm.id",
                "pm.privilege_id",
                "route_name",
                "parent_id",
                "text",
                "serial_no",
                "link_flag"
            )->get();
       // dd($active_menus);
        // $active_menus = DB::table("portal_menus AS pm")
        //     ->join("privileges AS p", function ($query) {
        //         $query->on("p.id", "=", "pm.privilege_id")
        //             ->where("p.active_flag", 1);
        //     })->join("roles_privileges AS rp", function ($query) use ($role_id) {
        //         $query->on("rp.privilege_id", "=", "p.id")
        //             ->where("rp.role_id", $role_id)
        //             ->OrWhereRaw("(rp.create=1 AND p.create=1 AND pm.create=1)
        //              OR (rp.read=1 AND p.read=1 AND pm.read=1) 
        //              OR (rp.update=1 AND p.update=1 AND pm.update=1)
        //              OR (rp.delete=1 AND p.delete=1 AND pm.delete=1)");
        //     })->where(["pm.link_flag" => 1, "pm.active_flag" => 1])
        //     ->groupBy(
        //         "pm.id",
        //         "route_name",
        //         "parent_id",
        //         "text",
        //         "serial_no",
        //         "link_flag"
        //     )
        //     ->select(
        //         "pm.id",
        //         "route_name",
        //         "parent_id",
        //         "text",
        //         "serial_no",
        //         "link_flag"
        //     )->get();

           
        $parent_links = $active_menus->where("parent_id", null);
        $children_links = $active_menus->where("parent_id", "<>", null);
        $nested_menus = $this->findParents($children_links);

        foreach ($parent_links as $parent_link) {
            $nested_menus->add($parent_link);
        }
        $links = $nested_menus->sortBy("serial_no")->values()->all();

        return $links;
    }


    private function findParents(Collection $collections)
    {
        //return $collections;
        //dd($collections);
        $parent_ids = $collections->where("parent_id", "<>", null)->pluck("parent_id")->unique()->toArray();
       // return $parent_ids;
        if (count($parent_ids) > 0) {

            $menus = DB::table("portal_menus")
                ->where("active_flag", 1)
                ->select("id", "link_flag", "parent_id", "text", "serial_no")
                ->whereIn("id", $parent_ids)->get();
           // return $menus;

            $new_collection = new Collection();
            foreach ($menus as $menu) {

                $sub_menus = $collections->where("parent_id", $menu->id);

                $menu->sub_menus = $sub_menus->values()->all();

                $new_collection->push($menu);
            }

           // return $new_collection;


            $new_collection = $this->findPairs($new_collection);
            //return $new_collection;

            return $this->findParents($new_collection);
        } else {
            return $collections;
        }
    }


    private function findPairs(Collection $collections)
    {
        $possible_children = $collections->where("parent_id", "<>", null);

        $possible_parents = $collections->where("parent_id", null);

        $children_ids = $possible_children->pluck("parent_id")->unique()->toArray();

        $parents_found = $possible_parents->whereIn("id", $children_ids);

        if ($parents_found->count() > 0) {

            $new_collections = new Collection();

            $found_parent_ids = $parents_found->pluck("id")->unique()->toArray();

            $no_parent_children = $possible_children->whereNotIn("parent_id", $found_parent_ids)->values()->all();

            $no_child_parents = $possible_parents->whereNotIn("id", $found_parent_ids);
            foreach ($parents_found as $parent) {
                $children_found = $possible_children->where("parent_id", $parent->id);

                $new_children = $children_found->values()->all();
                $children_collection = array_merge($parent->sub_menus, $new_children);
                $parent->sub_menus = $children_collection;
                $new_collections->push($parent);
            }
            if (count($no_parent_children)) {

                $new_collections->push($no_parent_children);
            }

            if (count($no_child_parents)) {
                //dd($no_child_parents);
                foreach ($no_child_parents as $child) {
                    $new_collections->add($child);
                }
            }

            return $new_collections;
        } else {
            return $collections;
        }
    }
}
